'use strict';

/* ADDEVENTLISTENER EVENT
***************************************************/

var goto = function goto(el, event, func) {
  return el.addEventListener(event, func, false);
};

/* RUN SCRIPTS WHEN ELEMENTOR LOADED ( FOR PREVIEW MODE ONLY )
***************************************************/
var onElementorLoaded = function onElementorLoaded(callback) {
  if (undefined === window.elementorFrontend || undefined === window.elementorFrontend.hooks) {
    setTimeout(function () {
      return onElementorLoaded(callback);
    });
    return;
  }
  callback();
};

/* WIDGET TOUR-POST: CAROUSEL LAYOUT
***************************************************/
var tourCarousel = function tourCarousel() {
  var el = document.getElementsByClassName('wd-tours-layout-carousel'),
      eleng = el.length,
      i = void 0;

  if (eleng < 1) return;

  for (i = 0; i < eleng; i++) {
    var c = el[i].getElementsByClassName('wd-tours-content')[0];
    if (c.classList.contains('tns-slider')) continue;

    var opt = JSON.parse(c.getAttribute('data-tiny-slider'));
    opt.container = c;

    var slider = tns(opt);
  }
};

/* WIDGET DESTINATION: CAROUSEL LAYOUT
***************************************************/
var destCarousel = function destCarousel() {
  var el = document.getElementsByClassName('wd-dest-layout-carousel'),
      eleng = el.length,
      i = void 0;

  if (eleng < 1) return;

  for (i = 0; i < eleng; i++) {
    var c = el[i].getElementsByClassName('wd-dest-content')[0];
    if (c.classList.contains('tns-slider')) continue;

    var opt = JSON.parse(c.getAttribute('data-tiny-slider'));
    opt.container = c;

    var slider = tns(opt);
  }
};

/* WIDGET COUNTDOWN
***************************************************/
var countDown = function countDown() {
  var el = document.getElementsByClassName('wd-countdown'),
      elen = el.length,
      i = void 0;
  if (elen < 1) return;

  for (i = 0; i < elen; i++) {
    var _date = el[i].getAttribute('data-date'),
        days_id = el[i].getElementsByClassName('wdcd-time')[0].id,
        hours_id = el[i].getElementsByClassName('wdcd-time')[1].id,
        mins_id = el[i].getElementsByClassName('wdcd-time')[2].id,
        secs_id = el[i].getElementsByClassName('wdcd-time')[3].id;

    var counter = Doom({
      targetDate: _date,
      ids: {
        days: days_id,
        hours: hours_id,
        mins: mins_id,
        secs: secs_id
      }
    });

    counter.doom();
  }
};

/* PAGE SETTINGS
***************************************************/
var pageSettings = function pageSettings() {
  if (typeof elementor == 'undefined' || typeof elementor.settings.page == 'undefined') return;

  var elementorAction = function elementorAction() {
    elementor.reloadPreview();
    elementor.once('preview:loaded', function () {
      return elementor.getPanelView().setPage('page_settings');
    });
  };

  /*FEATURE IMAGE*/
  elementor.settings.page.addChangeCallback('post_featured_image', function (newValue) {
    elementor.saver.update({
      onSuccess: function onSuccess() {
        var _pageHeader = document.getElementsByClassName('page-header')[0];
        if (!_pageHeader) return;

        if (newValue.url) {
          _pageHeader.style.backgroundImage = 'url( ' + newValue.url + ' )';
        } else {
          _pageHeader.style.removeProperty('background-image');
        }
      }
    });
  });

  /*PAGE MENU LAYOUT*/
  elementor.settings.page.addChangeCallback('page_menu_layout', function (newValue) {
    elementor.saver.update({
      onSuccess: function onSuccess() {
        elementorAction();
      }
    });
  });

  /*PAGE HEADER*/
  elementor.settings.page.addChangeCallback('page_header', function (newValue) {
    elementor.saver.update({
      onSuccess: function onSuccess() {
        elementorAction();
      }
    });
  });

  /*SET DELAY TIME FOR ACTION*/
  var searchDelay = function () {
    var timer = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return function (callback, ms) {
      clearTimeout(timer);
      timer = setTimeout(callback, ms);
    };
  }();

  /*PAGE HEADER HEIGHT*/
  elementor.settings.page.addChangeCallback('page_header_height', function (newValue) {
    searchDelay(function () {
      elementor.saver.update({
        onSuccess: function onSuccess() {
          elementorAction();
        }
      });
    }, 1000);
  });

  /*PAGE HEADER SPACE*/
  elementor.settings.page.addChangeCallback('page_header_space', function (newValue) {
    searchDelay(function () {
      elementor.saver.update({
        onSuccess: function onSuccess() {
          elementorAction();
        }
      });
    }, 1000);
  });

  /*PAGE FOOTER*/
  elementor.settings.page.addChangeCallback('page_footer', function (newValue) {
    elementor.saver.update({
      onSuccess: function onSuccess() {
        elementorAction();
      }
    });
  });
};

/* ON ELEMENTOR LOADED
 ***************************************************/
goto(document, 'DOMContentLoaded', function () {

  onElementorLoaded(function () {
    window.elementorFrontend.hooks.addAction('frontend/element_ready/global', function () {
      tourCarousel();
      destCarousel();
      countDown();
    });

    pageSettings();
  });
});