// @codingStandardsIgnoreStart
'use strict';

(function ($, window, document, undefined) {

    var pluginName = 'goto_menu',
        oldWindowWidth = 0,
        defaults = {
        resizeWidth: '992',
        animSpeed: 'fast',
        easingEffect: 'linear'
    };

    function Plugin(element, options) {
        this.element = element;
        this.$elem = jQuery(this.element);
        this.options = jQuery.extend(defaults, options);
        this.init();
    }

    Plugin.prototype = {

        init: function init() {
            var _window = jQuery(window),
                _options = this.options,
                _menu = this.$elem,
                _collapser = '<span class="menu-collapse-btn"><span></span></span>',
                _menuCollapser;

            _menu.before(_collapser);
            _menuCollapser = _menu.prev('.menu-collapse-btn');

            _menu.on('click', '.menu-item-has-children > .menu-icon-arrow', function (e) {
                e.preventDefault();
                e.stopPropagation();

                var _li = jQuery(this).closest('li');

                if (jQuery(this).hasClass('expanded')) {
                    jQuery(this).removeClass('expanded');
                    _li.find('>ul').slideUp(_options.animSpeed, _options.easingEffect);
                } else {
                    jQuery(this).addClass('expanded');
                    _li.find('>ul').slideDown(_options.animSpeed, _options.easingEffect);
                }
            });

            if (window.matchMedia('( max-width: 991px )').matches) {
                jQuery('.logo').clone().prependTo('.theme-primary-menu');
            }

            _menuCollapser.on('click', function (e) {
                e.preventDefault();
                _menu.toggleClass('menu-opened');
                _menuCollapser.toggleClass('active-btn');
                jQuery(document.body).toggleClass('mobile-menu-open');
            });

            document.getElementById('menu-overlay').addEventListener('click', function () {
                document.body.classList.remove('mobile-menu-open');
                _menu.removeClass('menu-opened');
                _menuCollapser.removeClass('active-btn');
            });

            this.resizeMenu();
            _window.on('resize', this.resizeMenu.bind(this));
            _window.trigger('resize');
        },

        resizeMenu: function resizeMenu() {
            var _window = jQuery(window),
                _windowWidth = _window.width(),
                _options = this.options,
                _menu = jQuery(this.element),
                _menuCollapser = jQuery(document.body).find('.menu-collapse-btn');

            if (undefined !== window['innerWidth'] && window['innerWidth'] > _windowWidth) {
                _windowWidth = window['innerWidth'];
            }

            if (_windowWidth != oldWindowWidth) {
                oldWindowWidth = _windowWidth;

                _menu.find('li').each(function () {
                    if (jQuery(this).has('a+ul').length) {

                        // Append new arrow element.
                        jQuery(this).append('<span class="menu-icon-arrow"></span>');
                    }
                    jQuery(this).children('a+ul').hide();
                });

                if (_options.resizeWidth >= _windowWidth) {
                    _menu.addClass('collapsed').find('li').has('a+ul').off('mouseenter mouseleave');

                    /*hide menu content when `resize`*/
                    _menu.removeClass('menu-opened');
                    _menuCollapser.removeClass('active-btn');
                } else {
                    _menu.find('.sub-menu').removeProp('style');
                    _menu.removeClass('collapsed');
                }
            }
        }
    };

    $.fn[pluginName] = function (options) {
        return this.each(function () {
            if (!$.data(this, 'plugin_' + pluginName)) {
                $.data(this, 'plugin_' + pluginName, new Plugin(this, options));
            }
        });
    };
})(jQuery, window, document);